ete2.treeview.drawer.NewickDialog

Package ete2 :: Package treeview :: Module drawer :: Class NewickDialog |
[hide private]
[frames] | no frames]

# Class NewickDialog

source code

           object --+
                    |
    sip.simplewrapper --+
                        |
              sip.wrapper --+
                            |
         PyQt4.QtCore.QObject --+
                                |
               object --+       |
                        |       |
        sip.simplewrapper --+   |
                            |   |
     PyQt4.QtGui.QPaintDevice --+
                                |
              PyQt4.QtGui.QWidget --+
                                    |
                  PyQt4.QtGui.QDialog --+
                                        |
                                       NewickDialog

Nested Classes | [hide private]
Inherited from `PyQt4.QtGui.QDialog`: `DialogCode` Inherited from `PyQt4.QtGui.QWidget`: `RenderFlag`, `RenderFlags` Inherited from `PyQt4.QtGui.QPaintDevice`: `PaintDeviceMetric`

Instance Methods | [hide private]
__init__(self, node, *args) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
update_newick(self) | source code
add_feature(self) | source code
del_feature(self) | source code
set_custom_features(self) | source code
Inherited from `PyQt4.QtGui.QDialog`: `accept`, `accepted`, `actionEvent`, `changeEvent`, `childEvent`, `closeEvent`, `connectNotify`, `contextMenuEvent`, `create`, `customEvent`, `destroy`, `disconnectNotify`, `done`, `dragEnterEvent`, `dragLeaveEvent`, `dragMoveEvent`, `dropEvent`, `enabledChange`, `enterEvent`, `event`, `eventFilter`, `exec_`, `extension`, `finished`, `focusInEvent`, `focusNextChild`, `focusNextPrevChild`, `focusOutEvent`, `focusPreviousChild`, `fontChange`, `hideEvent`, `inputMethodEvent`, `isSizeGripEnabled`, `keyPressEvent`, `keyReleaseEvent`, `languageChange`, `leaveEvent`, `metric`, `minimumSizeHint`, `mouseDoubleClickEvent`, `mouseMoveEvent`, `mousePressEvent`, `mouseReleaseEvent`, `moveEvent`, `open`, `orientation`, `paintEvent`, `paletteChange`, `receivers`, `reject`, `rejected`, `resetInputContext`, `resizeEvent`, `result`, `setExtension`, `setModal`, `setOrientation`, `setResult`, `setSizeGripEnabled`, `setVisible`, `showEvent`, `showExtension`, `sizeHint`, `tabletEvent`, `timerEvent`, `updateMicroFocus`, `wheelEvent`, `windowActivationChange` Inherited from `PyQt4.QtGui.QWidget`: `acceptDrops`, `accessibleDescription`, `accessibleName`, `actions`, `activateWindow`, `addAction`, `addActions`, `adjustSize`, `autoFillBackground`, `backgroundRole`, `baseSize`, `childAt`, `childrenRect`, `childrenRegion`, `clearFocus`, `clearMask`, `close`, `contentsRect`, `contextMenuPolicy`, `cursor`, `customContextMenuRequested`, `devType`, `effectiveWinId`, `ensurePolished`, `find`, `focusPolicy`, `focusProxy`, `focusWidget`, `font`, `fontInfo`, `fontMetrics`, `foregroundRole`, `frameGeometry`, `frameSize`, `geometry`, `getContentsMargins`, `grabKeyboard`, `grabMouse`, `grabShortcut`, `graphicsProxyWidget`, `handle`, `hasFocus`, `hasMouseTracking`, `height`, `heightForWidth`, `hide`, `inputContext`, `inputMethodQuery`, `insertAction`, `insertActions`, `isActiveWindow`, `isAncestorOf`, `isEnabled`, `isEnabledTo`, `isEnabledToTLW`, `isFullScreen`, `isHidden`, `isLeftToRight`, `isMaximized`, `isMinimized`, `isModal`, `isRightToLeft`, `isTopLevel`, `isVisible`, `isVisibleTo`, `isWindow`, `isWindowModified`, `keyboardGrabber`, `layout`, `layoutDirection`, `locale`, `lower`, `mapFrom`, `mapFromGlobal`, `mapFromParent`, `mapTo`, `mapToGlobal`, `mapToParent`, `mask`, `maximumHeight`, `maximumSize`, `maximumWidth`, `minimumHeight`, `minimumSize`, `minimumWidth`, `mouseGrabber`, `move`, `nativeParentWidget`, `nextInFocusChain`, `normalGeometry`, `overrideWindowFlags`, `overrideWindowState`, `paintEngine`, `palette`, `parentWidget`, `pos`, `raise_`, `rect`, `releaseKeyboard`, `releaseMouse`, `releaseShortcut`, `removeAction`, `render`, `repaint`, `resize`, `restoreGeometry`, `saveGeometry`, `scroll`, `setAcceptDrops`, `setAccessibleDescription`, `setAccessibleName`, `setAttribute`, `setAutoFillBackground`, `setBackgroundRole`, `setBaseSize`, `setContentsMargins`, `setContextMenuPolicy`, `setCursor`, `setDisabled`, `setEnabled`, `setFixedHeight`, `setFixedSize`, `setFixedWidth`, `setFocus`, `setFocusPolicy`, `setFocusProxy`, `setFont`, `setForegroundRole`, `setGeometry`, `setHidden`, `setInputContext`, `setLayout`, `setLayoutDirection`, `setLocale`, `setMask`, `setMaximumHeight`, `setMaximumSize`, `setMaximumWidth`, `setMinimumHeight`, `setMinimumSize`, `setMinimumWidth`, `setMouseTracking`, `setPalette`, `setParent`, `setShortcutAutoRepeat`, `setShortcutEnabled`, `setShown`, `setSizeIncrement`, `setSizePolicy`, `setStatusTip`, `setStyle`, `setStyleSheet`, `setTabOrder`, `setToolTip`, `setUpdatesEnabled`, `setWhatsThis`, `setWindowFilePath`, `setWindowFlags`, `setWindowIcon`, `setWindowIconText`, `setWindowModality`, `setWindowModified`, `setWindowOpacity`, `setWindowRole`, `setWindowState`, `setWindowTitle`, `show`, `showFullScreen`, `showMaximized`, `showMinimized`, `showNormal`, `size`, `sizeIncrement`, `sizePolicy`, `stackUnder`, `statusTip`, `style`, `styleSheet`, `testAttribute`, `toolTip`, `topLevelWidget`, `underMouse`, `unsetCursor`, `unsetLayoutDirection`, `unsetLocale`, `update`, `updateGeometry`, `updatesEnabled`, `visibleRegion`, `whatsThis`, `width`, `winId`, `window`, `windowFilePath`, `windowFlags`, `windowIcon`, `windowIconText`, `windowModality`, `windowOpacity`, `windowRole`, `windowState`, `windowTitle`, `windowType`, `x`, `x11Info`, `x11PictureHandle`, `y` Inherited from `PyQt4.QtCore.QObject`: `blockSignals`, `children`, `connect`, `deleteLater`, `destroyed`, `disconnect`, `dumpObjectInfo`, `dumpObjectTree`, `dynamicPropertyNames`, `emit`, `findChild`, `findChildren`, `inherits`, `installEventFilter`, `isWidgetType`, `killTimer`, `metaObject`, `moveToThread`, `objectName`, `parent`, `property`, `pyqtConfigure`, `removeEventFilter`, `sender`, `setObjectName`, `setProperty`, `signalsBlocked`, `startTimer`, `thread`, `tr`, `trUtf8` Inherited from `PyQt4.QtGui.QPaintDevice`: `depth`, `heightMM`, `logicalDpiX`, `logicalDpiY`, `numColors`, `paintingActive`, `physicalDpiX`, `physicalDpiY`, `widthMM` Inherited from `sip.simplewrapper`: `__delattr__`, `__getattribute__`, `__new__`, `__setattr__` Inherited from `object`: `__format__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `PyQt4.QtGui.QDialog`: `Accepted`, `Rejected` Inherited from `PyQt4.QtGui.QWidget`: `DrawChildren`, `DrawWindowBackground`, `IgnoreMask` Inherited from `PyQt4.QtCore.QObject`: `staticMetaObject` Inherited from `PyQt4.QtGui.QPaintDevice`: `PdmDepth`, `PdmDpiX`, `PdmDpiY`, `PdmHeight`, `PdmHeightMM`, `PdmNumColors`, `PdmPhysicalDpiX`, `PdmPhysicalDpiY`, `PdmWidth`, `PdmWidthMM`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, node, *args) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)